@@ -12,7 +12,7 @@ use warnings;
 use Carp qw/croak/;
 use Scalar::Util qw/looks_like_number reftype/;
 
-our $VERSION = '0.52';
+our $VERSION = '0.60';
 
 # To avoid file reader from wasting too much time on bum input (longest
 # scala file 'fortune.scl' in archive as of 2013-02-19 has 617 lines).
@@ -22,10 +22,18 @@ my $MAX_LINES = 3000;
 #
 # SUBROUTINES
 
+sub cents2ratio {
+  my ( $self, $cents, $precision ) = @_;
+  croak 'cents must be a number' if !looks_like_number $cents;
+  $precision //= 2;
+
+  return sprintf "%.*f", $precision, 10**( $cents / 3986.31371386484 );
+}
+
 # MIDI calculation, for easy comparison to scala results
 sub freq2pitch {
   my ( $self, $freq ) = @_;
-  croak "frequency must be a positive number"
+  croak 'frequency must be a positive number'
     if !looks_like_number $freq
     or $freq < 0;
 
@@ -180,6 +188,15 @@ sub pitch2freq {
     ( 2**( ( $pitch - $self->{_concertpitch} ) / 12 ) );
 }
 
+sub ratio2cents {
+  my ( $self, $ratio, $precision ) = @_;
+  croak 'ratio must be a number' if !looks_like_number $ratio;
+  $precision //= 2;
+
+  return sprintf "%.*f", $precision,
+    1200 * ( ( log($ratio) / 2.30258509299405 ) / 0.301029995663981 );
+}
+
 sub read_scala {
   my $self = shift;
   my %param;
@@ -398,6 +415,8 @@ Music::Scala - Scala scale support for Perl
   $scala->pitch2freq(69);
   $scala->freq2pitch(440);
 
+And more...
+
 =head1 DESCRIPTION
 
 Scala scale support for Perl: reading, writing, setting, and interval to
@@ -412,6 +431,10 @@ to bad input. B<new> would be a good one to start with.
 
 =over 4
 
+=item B<cents2ratio> I<cents>
+
+Converts a value in cents (e.g. 1200) to a ratio (e.g. 2).
+
 =item B<freq2pitch> I<frequency>
 
 Converts the passed frequency (Hz) to the corresponding MIDI pitch
@@ -489,7 +512,11 @@ point math:
 
   $scala->interval2freq(1);   # 879.999999999999
 
-  sprintf "%.2f", $scala->interval2freq(1); # 880.00
+  sprintf "%.*f", 0, $scala->interval2freq(1);   # 880
+
+L<http://docs.oracle.com/cd/E19957-01/806-3568/ncg_goldberg.html> "What
+Every Computer Scientist Should Know About Floating-Point Arithmetic".
+David Goldberg, Computing Surveys, March 1991.
 
 =item B<new> I<optional_params>, ...
 
@@ -549,6 +576,10 @@ Converts the given MIDI pitch number to a frequency using the MIDI
 conversion algorithm (equal temperament), as influenced by the
 I<concertfreq> setting.
 
+=item B<ratio2cents> I<ratio>
+
+Converts a ratio (e.g. 2) to a value in cents (e.g. 1200).
+
 =item B<read_scala> I<filename>
 
 Parses a scala file. Will throw some kind of exception if anything at
